@@ -28,7 +28,15 @@ def cal_g160(cleanFile,inFile,outFile,inOffset,outOffset,maxComNLevel=-48.0,spee
     :return:
     """
     g160 = g160Struct()
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/g160.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/g160.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/g160.dylib')
+
     cleFile = c_char_p(bytes(cleanFile.encode('utf-8')))#create_unicode_buffer(cleanFile.encode('utf-8'), len(cleanFile))
     inputFile = c_char_p(bytes(inFile.encode('utf-8')))#create_unicode_buffer(inFile.encode('utf-8'), len(inFile))
     outputFile = c_char_p(bytes(outFile.encode('utf-8')))#create_unicode_buffer(outFile.encode('utf-8'), len(outFile))
