@@ -51,12 +51,19 @@ def polqa_client_test(src,test,samplerate):
 
 
 if __name__ == '__main__':
+    # import platform
+    # print(platform.uname())
+    # print(sys.platform)
+    # exit(0)
     # client, sftp = sftp_connect(username, password, serverIP, port=port)
     # sftp_get(sftp, '/home/netease/polqa_result/' + '192.168.1.3_2021-08-18-17-52-35' + '.ress', 'result')
-    src = r'E:\AIVAD\OTHER\maleChinesePOLQASWB.pcm'
+    src = r'D:\0\speech_cn_minus_13.pcm'
+    test1 = r'D:\0\mixDstFile_minus_13.pcm'
+    test2 = r'D:\0\mixDstFile_minus_13_-6.pcm'
     refout = r'E:\AIVAD\OTHER\ref_out0_01.pcm'
     file = r'E:\AIVAD\OTHER\reverse0_01.pcm'
-    info = polqa_client_test(src, refout, 48000)
+    info = polqa_client_test(src, test1, 48000)
+    info = polqa_client_test(src, test2, 48000)
     exit(0)
     path = r'E:\02_POLQA_RESULT\testDstFiles\NERTC_iphone11_honor8x_V4.3.0\L\Speech_48000\NONE\female\femalePOLQASWB'
     src = r'E:\01_MOS_AUTO_TESTER\testSrcFiles\Speech_48000\female\femalePOLQASWB.pcm'
